@@ -40,7 +40,6 @@ from collections import defaultdict
 import os
 import sys
 from contextlib import contextmanager
-import pandas as pd
 import json
 from six import iteritems
 from spylon.common import as_iterable
@@ -220,6 +219,7 @@ def _tree():
 
 
 def _fetch_documentation(version, base_url="https://spark.apache.org/docs"):
+    import pandas as pd
     doc_urls = [
         "{base_url}/{version}/configuration.html",
         "{base_url}/{version}/sql-programming-guide.html",
@@ -569,6 +569,11 @@ class SparkConfiguration(object):
         sqlContext = pyspark.SQLContext(sc)
         return (sc, sqlContext)
 
+    def spark_session(self, application_name):
+        sc = self.spark_context(application_name)
+        from pyspark.sql import SparkSession
+        return SparkSession(sc)
+
 
 default_configuration = SparkConfiguration()
 
@@ -587,7 +592,7 @@ def with_spark_context(application_name, conf=None):
     sc : SparkContext
 
     Examples
-    -------
+    --------
     Used within a context manager
     >>> with with_spark_context("MyApplication") as sc:
     ...     # Your Code here
@@ -615,7 +620,7 @@ def with_sql_context(application_name, conf=None):
     sql_context: SQLContext
 
     Examples
-    -------
+    --------
     Used within a context manager
     >>> with with_sql_context("MyApplication") as (sc, sql_context):
     ...     import pyspark
